@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2008 Sergey Poznyakoff
+   Copyright (C) 2008-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 static int libdico_initialized;
 
 void
-_dico_libi18n_init()
+_dico_libi18n_init(void)
 {
     if (!libdico_initialized) {
 	bindtextdomain(PACKAGE, LOCALEDIR);
