@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 1998-2016 Sergey Poznyakoff
+   Copyright (C) 1998-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #include <sysexits.h>
 
 void
-xalloc_die()
+xalloc_die(void)
 {
     dico_die(EX_OSERR, L_CRIT, 0, "Not enough memory");
 }
