@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico
-   Copyright (C) 2008, 2010, 2012 Sergey Poznyakoff
+   Copyright (C) 2008-2018 Sergey Poznyakoff
   
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include <xgetdomainname.h>
 
 char *
-xdico_local_hostname()
+xdico_local_hostname(void)
 {
     struct hostent *hp;
     char *hostpart = xgethostname();
